@@ -14,6 +14,9 @@ class JsonStorage:
                 return data
         except FileNotFoundError:
             print("File was not found!")
+        except TypeError as _error:
+            print(f"Type Error: {_error}")
+            print(f"File name: {file_name}")
 
     def write_json_file(self, data, file_name):
         try:
@@ -21,12 +24,18 @@ class JsonStorage:
                 json.dump(data, file, indent=4)
         except FileNotFoundError:
             print("File was not found!")
+        except TypeError as _error:
+            print(f"Type Error: {_error}")
+            print(f"File name: {file_name}")
 
     def read_json_file_table(self, file_name, table: str):
         try:
             return self.read_json_file(file_name)[table]
         except KeyError:
             print("Table wasn't found!")
+        except TypeError as _error:
+            print(f"Type Error: {_error}")
+            print(f"File name: {file_name}, Table name: {table}")
 
     def write_json_file_table(self, file_name, table: str, input_data):
         data = {table: input_data}
@@ -34,3 +43,6 @@ class JsonStorage:
             self.write_json_file(data, file_name)
         except KeyError:
             print("Table wasn't found!")
+        except TypeError as _error:
+            print(f"Type Error: {_error}")
+            print(f"File name: {file_name}, Table name: {table}")
